@@ -1,11 +1,14 @@
-import types
+import datetime
 import logging
+import re
+import threading
+import types
 
-from django.utils.html import escape
 from django.utils.encoding import force_unicode
 
 logger = logging.getLogger(__name__)
 
+
 class JSVar(unicode):
     """
     A JS variable.
@@ -107,7 +110,7 @@ def convert_py_to_js_data(val, id_):
     elif isinstance(val, JSFunctionInContext):
         return u"django_select2.runInContextHelper(%s, '%s')" % (val, id_)
     elif isinstance(val, JSVar):
-        return val # No quotes here
+        return val  # No quotes here
     elif isinstance(val, dict):
         return convert_dict_to_js_map(val, id_)
     elif isinstance(val, list):
@@ -184,11 +187,6 @@ def convert_to_js_string_arr(lst):
 
 ### Auto view helper utils ###
 
-import re
-import threading
-import datetime
-
-
 def synchronized(f):
     "Decorator to synchronize multiple calls to a functions."
     f.__lock__ = threading.Lock()
@@ -200,9 +198,10 @@ def synchronized(f):
     synced_f.__doc__ = f.__doc__
     return synced_f
 
-
-__id_store = {} # Generated Id to field instance mapping.
-__field_store = {} # Field's key to generated Id mapping.
+# Generated Id to field instance mapping.
+__id_store = {}
+# Field's key to generated Id mapping.
+__field_store = {}
 
 
 ID_PATTERN = r"[0-9_a-zA-Z.:+\- ]+"
@@ -271,3 +270,30 @@ def get_field(id_):
     """
     return __id_store.get(id_, None)
 
+def timer_start(name):
+    import sys, time
+    if sys.platform == "win32":
+        # On Windows, the best timer is time.clock()
+        default_timer = time.clock
+        multiplier = 1.0
+    else:
+        # On most other platforms the best timer is time.time()
+        default_timer = time.time
+        multiplier = 1000.0
+
+    return (name, default_timer, multiplier, default_timer())
+
+def timer_end(t):
+    (name, default_timer, multiplier, timeS) = t
+    timeE = default_timer()
+    logger.debug("Time taken by %s: %0.3f ms" % (name, (timeE - timeS) * multiplier))
+
+def timer(f):
+    def inner(*args, **kwargs):
+        
+        t = timer_start(f.func_name)
+        ret = f(*args, **kwargs)
+        timer_end(t)
+
+        return ret
+    return inner
